/***************************************************************************
                          kxe_viewelement.cpp  -  description
                             -------------------
    begin                : Mon Oct 15 2001
    copyright            : (C) 2001, 2002, 2003 by The KXMLEditor Team
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kxe_viewelement.h"
#include "kxe_viewattributes.h"
#include "kxesyntaxhighlighter.h"
#include "dlgconfiguration.h"

#include <kconfig.h>

#include <qmultilineedit.h>
#include <qdom.h>
#include <qcolor.h>

#include "qdom_add.h"

#define CONFIG_SPLITTER_SIZES "View Element splitter sizes"

KXE_ViewElement::KXE_ViewElement( QWidget * pParent, KConfig *pConfig, const char * pszName )
	: QSplitter( Qt::Vertical, pParent, pszName )
{
	setOpaqueResize(true);
	m_pConfig = pConfig;
	m_pViewAttributes = new KXE_ViewAttributes( this, "table of element attributes");
	connect( m_pViewAttributes, SIGNAL(sigContextMenuRequested(const QString&,const QPoint&)), this, SIGNAL(sigContextMenuRequested(const QString&,const QPoint&)) );

  connect( m_pViewAttributes, SIGNAL(sigAttributeNameChangedInplace(const QDomAttr&, const QString)), this, SIGNAL(sigAttributeNameChangedInplace(const QDomAttr&, const QString)) );
  connect( m_pViewAttributes, SIGNAL(sigAttributeValueChangedInplace(const QDomAttr&, const QString)), this, SIGNAL(sigAttributeValueChangedInplace(const QDomAttr&, const QString)) );

	m_pViewPlainXML = new QMultiLineEdit( this, "plain XML" );
	m_pViewPlainXML->setReadOnly(true);
  m_pSyntaxHighlighter = new KXESyntaxHighlighter(m_pViewPlainXML);

  	// configuring spliiter sizes
	if (m_pConfig)
	{
		QValueList<int> list = m_pConfig->readIntListEntry(CONFIG_SPLITTER_SIZES);
		if (!list.isEmpty())
			setSizes(list);
        }
}

KXE_ViewElement::~KXE_ViewElement()
{
	// saving splitter sizes
	if (m_pConfig)
		m_pConfig->writeEntry( CONFIG_SPLITTER_SIZES, sizes() );

  delete m_pSyntaxHighlighter;
}

QDomAttr KXE_ViewElement::getSelectedAttribute() const
{
	return m_pViewAttributes->getSelectedAttribute();
}

void KXE_ViewElement::setReadWrite( bool fReadWrite )
{
	m_pViewAttributes->setReadWrite(fReadWrite);
}

void KXE_ViewElement::slotChange( const QDomElement & element )
{
	// change attribute view
	m_pViewAttributes->slotChange(element);

	// change plain XML view
	m_pViewPlainXML->setText( domTool_save(element) );
}

//////////////////////////////////////////////////////////////
// configuration slots
//////////////////////////////////////////////////////////////

void KXE_ViewElement::slotConfigurationChanged( const KXEConfigurationDialog * const pNewConfiguration )
{
  m_pSyntaxHighlighter->setColorDefaultText(pNewConfiguration->colorDefaultText());
  m_pSyntaxHighlighter->setColorElementNames(pNewConfiguration->colorElementNames());
  m_pSyntaxHighlighter->setColorAttributeNames(pNewConfiguration->colorAttributeNames());
  m_pSyntaxHighlighter->setColorAttributeValues(pNewConfiguration->colorAttributeValues());
  m_pSyntaxHighlighter->setColorXmlSyntaxChars(pNewConfiguration->colorXmlSyntaxChars());
  m_pSyntaxHighlighter->setColorComments(pNewConfiguration->colorComments());
  m_pSyntaxHighlighter->setColorSyntaxError(pNewConfiguration->colorSyntaxError());

  m_pSyntaxHighlighter->rehighlight();
}
