/***************************************************************************
                          kxetexteditordialog.cpp  -  description
                             -------------------
    begin                : Ne pro 14 2003
    copyright            : (C) 2003 by The KXMLEditor Team
    email                : lvanek.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "kxetexteditordialog.h"

#include <qdom.h>
#include <qpushbutton.h>

#include <kmessagebox.h>
#include <ktextedit.h>
#include <klocale.h>
#include <kdebug.h>

#include "dlgconfiguration.h"

KXETextEditorDialog::KXETextEditorDialog(QWidget *parent, const char *name)
  : KXETextEditorDialogBase(parent,name)
{
  m_pSyntaxHighlighter = new KXESyntaxHighlighter(m_pTextEditor);

  connect( m_pTextEditor, SIGNAL(textChanged()), this, SLOT(slotTextChanged()) );
}

KXETextEditorDialog::~KXETextEditorDialog()
{
  delete m_pSyntaxHighlighter;
}

void KXETextEditorDialog::slotTextChanged()
{
	if ( m_pTextEditor->text().isEmpty()) 
		m_pButtonOk->setEnabled(false);
	else
		m_pButtonOk->setEnabled(true);
}

void KXETextEditorDialog::slotValidate()
{
  validateXml(true);
}

void KXETextEditorDialog::accept()
{
  if(validateXml(false))
    KXETextEditorDialogBase::accept();
}

bool KXETextEditorDialog::validateXml(bool bInfoIfOK)
{
  QString strXML = "<root>" + editorText()  + "</root>";

	// create XML documemt from text
	QString strErrorMsg;
  int iErrorLine, iErrorColumn;
	QDomDocument doc;

 	if(!doc.setContent(strXML, true, &strErrorMsg, &iErrorLine, &iErrorColumn) )
 	{ kdDebug() << "KXETextEditorDialog::validateXml: Failed parsing the file." << endl;

    KMessageBox::error(this,
									 		i18n("%1 in line %2, column %3").arg(strErrorMsg).arg(iErrorLine).arg(iErrorColumn),
									 		i18n("Parsing error !"));


    m_pTextEditor->setCursorPosition(iErrorLine - 1, iErrorColumn - 1);
    
    return false;
	}

  // check if root item already exists
	if(!doc.firstChild().firstChild().isElement())
		{ KMessageBox::sorry(this, i18n("You are changed root element to another node type, while editing !"));
			return false;
		}

  if(bInfoIfOK)
    KMessageBox::information(this, i18n("OK"));
			
  return true;
}

void KXETextEditorDialog::setConfiguration( const KXEConfigurationDialog * const pNewConfiguration )
{
  m_pSyntaxHighlighter->setColorDefaultText(pNewConfiguration->colorDefaultText());
  m_pSyntaxHighlighter->setColorElementNames(pNewConfiguration->colorElementNames());
  m_pSyntaxHighlighter->setColorAttributeNames(pNewConfiguration->colorAttributeNames());
  m_pSyntaxHighlighter->setColorAttributeValues(pNewConfiguration->colorAttributeValues());
  m_pSyntaxHighlighter->setColorXmlSyntaxChars(pNewConfiguration->colorXmlSyntaxChars());
  m_pSyntaxHighlighter->setColorComments(pNewConfiguration->colorComments());
  m_pSyntaxHighlighter->setColorSyntaxError(pNewConfiguration->colorSyntaxError());
}
